==> openturns_1.3~rc1.orig.tar.bz2: openturns-1.3rc1/lib/test/t_Student_std.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  t_Student_std.cxx
 *  @brief The test file of class Student for standard methods
 *
 *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
 *
 *  This library is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  @author schueller
 *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
 */
#include "OT.hxx"
#include "OTtestcode.hxx"

using namespace OT;
using namespace OT::Test;

class TestObject : public Student
{
public:
  explicit TestObject() : Student(5.0, -0.5, 2.0) {}
  explicit TestObject(const String & name) : Student(5.0, -0.5)
  {
    setName(name);
  }
  virtual ~TestObject() {}
};


int main(int argc, char *argv[])
{
  TESTPREAMBLE;
  OStream fullprint(std::cout);
  setRandomGenerator();

  try
  {
    // Test basic functionnalities
    checkClassWithClassName<TestObject>();

    // Test some extra functionnalities
    checkNameFeature<TestObject>();

    // Instanciate one distribution object
    Student distribution(6.5, -0.5, 5.0);
    fullprint << "Distribution " << distribution << std::endl;
    std::cout << "Distribution " << distribution << std::endl;

    // Is this distribution elliptical ?
    fullprint << "Elliptical = " << (distribution.isElliptical() ? "true" : "false") << std::endl;

    // Is this distribution continuous ?
    fullprint << "Continuous = " << (distribution.isContinuous() ? "true" : "false") << std::endl;

    // Test for realization of distribution
    NumericalPoint oneRealization = distribution.getRealization();
    fullprint << "oneRealization=" << oneRealization << std::endl;

    // Test for sampling
    UnsignedLong size = 10000;
    NumericalSample oneSample = distribution.getSample( size );
    fullprint << "oneSample first=" << oneSample[0] << " last=" << oneSample[size - 1] << std::endl;
    fullprint << "mean=" << oneSample.computeMean() << std::endl;
    fullprint << "covariance=" << oneSample.computeCovariance() << std::endl;
    size = 100;
    for (UnsignedLong i = 0; i < 2; ++i)
    {
      fullprint << "Kolmogorov test for the generator, sample size=" << size << " is " << (FittingTest::Kolmogorov(distribution.getSample(size), distribution).getBinaryQualityMeasure() ? "accepted" : "rejected") << std::endl;
      size *= 10;
    }

    // Define a point
    NumericalPoint point( distribution.getDimension(), 1.0 );
    fullprint << "Point= " << point << std::endl;

    // Show PDF and CDF of point
    NumericalScalar eps(1e-5);
    NumericalPoint DDF = distribution.computeDDF( point );
    fullprint << "ddf     =" << DDF << std::endl;
    fullprint << "ddf (FD)=" << NumericalPoint(1, (distribution.computePDF( point + NumericalPoint(1, eps) ) - distribution.computePDF( point  + NumericalPoint(1, -eps) )) / (2.0 * eps)) << std::endl;
    NumericalScalar LPDF = distribution.computeLogPDF( point );
    fullprint << "log pdf=" << LPDF << std::endl;
    NumericalScalar PDF = distribution.computePDF( point );
    fullprint << "pdf     =" << PDF << std::endl;
    fullprint << "pdf (FD)=" << (distribution.computeCDF( point + NumericalPoint(1, eps) ) - distribution.computeCDF( point  + NumericalPoint(1, -eps) )) / (2.0 * eps) << std::endl;
    NumericalScalar CDF = distribution.computeCDF( point );
    fullprint << "cdf=" << CDF << std::endl;
    NumericalScalar CCDF = distribution.computeComplementaryCDF( point );
    fullprint << "ccdf=" << CCDF << std::endl;
    NumericalScalar Survival = distribution.computeSurvivalFunction( point );
    fullprint << "survival=" << Survival << std::endl;
    NumericalPoint PDFgr = distribution.computePDFGradient( point );
    fullprint << "pdf gradient     =" << PDFgr << std::endl;
    NumericalPoint PDFgrFD(3);
    PDFgrFD[0] = (Student(distribution.getNu() + eps, distribution.getMean(), distribution.getSigma(), distribution.getCorrelation()).computePDF(point) -
                  Student(distribution.getNu() - eps, distribution.getMean(), distribution.getSigma(), distribution.getCorrelation()).computePDF(point)) / (2.0 * eps);
    PDFgrFD[1] = (Student(distribution.getNu(), distribution.getMean() + NumericalPoint(1, eps), distribution.getSigma(), distribution.getCorrelation()).computePDF(point) -
                  Student(distribution.getNu(), distribution.getMean() - NumericalPoint(1, eps), distribution.getSigma(), distribution.getCorrelation()).computePDF(point)) / (2.0 * eps);
    PDFgrFD[2] = (Student(distribution.getNu(), distribution.getMean(), distribution.getSigma() + NumericalPoint(1, eps), distribution.getCorrelation()).computePDF(point) -
                  Student(distribution.getNu(), distribution.getMean(), distribution.getSigma() - NumericalPoint(1, eps), distribution.getCorrelation()).computePDF(point)) / (2.0 * eps);
    fullprint << "pdf gradient (FD)=" << PDFgrFD << std::endl;
    NumericalPoint CDFgr = distribution.computeCDFGradient( point );
    fullprint << "cdf gradient     =" << CDFgr << std::endl;
    NumericalPoint CDFgrFD(3);
    CDFgrFD[0] = (Student(distribution.getNu() + eps, distribution.getMean(), distribution.getSigma(), distribution.getCorrelation()).computeCDF(point) -
                  Student(distribution.getNu() - eps, distribution.getMean(), distribution.getSigma(), distribution.getCorrelation()).computeCDF(point)) / (2.0 * eps);
    CDFgrFD[1] = (Student(distribution.getNu(), distribution.getMean() + NumericalPoint(1, eps), distribution.getSigma(), distribution.getCorrelation()).computeCDF(point) -
                  Student(distribution.getNu(), distribution.getMean() - NumericalPoint(1, eps), distribution.getSigma(), distribution.getCorrelation()).computeCDF(point)) / (2.0 * eps);
    CDFgrFD[2] = (Student(distribution.getNu(), distribution.getMean(), distribution.getSigma() + NumericalPoint(1, eps), distribution.getCorrelation()).computeCDF(point) -
                  Student(distribution.getNu(), distribution.getMean(), distribution.getSigma() - NumericalPoint(1, eps), distribution.getCorrelation()).computeCDF(point)) / (2.0 * eps);
    fullprint << "cdf gradient (FD)=" << CDFgrFD << std::endl;
    NumericalPoint quantile = distribution.computeQuantile( 0.95 );
    fullprint << "quantile=" << quantile << std::endl;
    fullprint << "cdf(quantile)=" << distribution.computeCDF(quantile) << std::endl;
    NumericalPoint mean = distribution.getMean();
    fullprint << "mean=" << mean << std::endl;
    NumericalPoint standardDeviation = distribution.getStandardDeviation();
    fullprint << "standard deviation=" << standardDeviation << std::endl;
    NumericalPoint skewness = distribution.getSkewness();
    fullprint << "skewness=" << skewness << std::endl;
    NumericalPoint kurtosis = distribution.getKurtosis();
    fullprint << "kurtosis=" << kurtosis << std::endl;
    CovarianceMatrix covariance = distribution.getCovariance();
    fullprint << "covariance=" << covariance << std::endl;
    CovarianceMatrix correlation = distribution.getCorrelation();
    fullprint << "correlation=" << correlation << std::endl;
    CovarianceMatrix spearman = distribution.getSpearmanCorrelation();
    fullprint << "spearman=" << spearman << std::endl;
    CovarianceMatrix kendall = distribution.getKendallTau();
    fullprint << "kendall=" << kendall << std::endl;
    Student::NumericalPointWithDescriptionCollection parameters = distribution.getParametersCollection();
    fullprint << "parameters=" << parameters << std::endl;
    for (UnsignedLong i = 0; i < 6; ++i) fullprint << "standard moment n=" << i << ", value=" << distribution.getStandardMoment(i) << std::endl;
    fullprint << "Standard representative=" << distribution.getStandardRepresentative()->__str__() << std::endl;

    // Specific to this distribution
    NumericalScalar beta(point.norm2());
    NumericalScalar densityGenerator(distribution.computeDensityGenerator(beta));
    fullprint << "density generator=" << densityGenerator << std::endl;
    fullprint << "pdf via density generator=" << distribution.EllipticalDistribution::computePDF(point) << std::endl;
    NumericalScalar densityGeneratorDerivative(distribution.computeDensityGeneratorDerivative(beta));
    fullprint << "density generator derivative     =" << densityGeneratorDerivative << std::endl;
    fullprint << "density generator derivative (FD)=" << (distribution.computeDensityGenerator(beta + eps) - distribution.computeDensityGenerator(beta - eps)) / (2.0 * eps) << std::endl;
    NumericalScalar densityGeneratorSecondDerivative(distribution.computeDensityGeneratorSecondDerivative(beta));
    fullprint << "density generator second derivative     =" << densityGeneratorSecondDerivative << std::endl;
    fullprint << "density generator second derivative (FD)=" << (distribution.computeDensityGeneratorDerivative(beta + eps) - distribution.computeDensityGeneratorDerivative(beta - eps)) / (2.0 * eps) << std::endl;

  }
  catch (TestFailed & ex)
  {
    std::cerr << ex << std::endl;
    return ExitCode::Error;
  }


  return ExitCode::Success;
}

==> openturns_1.4.orig.tar.bz2: openturns-1.4/lib/test/t_Student_std.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  t_Student_std.cxx
 *  @brief The test file of class Student for standard methods
 *
 *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
 *
 *  This library is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  @author schueller
 *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
 */
#include "OT.hxx"
#include "OTtestcode.hxx"

using namespace OT;
using namespace OT::Test;

class TestObject : public Student
{
public:
  TestObject() : Student(5.0, -0.5, 2.0) {}
  virtual ~TestObject() {}
};


int main(int argc, char *argv[])
{
  TESTPREAMBLE;
  OStream fullprint(std::cout);
  setRandomGenerator();

  try
  {
    // Test basic functionnalities
    checkClassWithClassName<TestObject>();

    // Instanciate one distribution object
    Student distribution(6.5, -0.5, 5.0);
    fullprint << "Distribution " << distribution << std::endl;
    std::cout << "Distribution " << distribution << std::endl;

    // Is this distribution elliptical ?
    fullprint << "Elliptical = " << (distribution.isElliptical() ? "true" : "false") << std::endl;

    // Is this distribution continuous ?
    fullprint << "Continuous = " << (distribution.isContinuous() ? "true" : "false") << std::endl;

    // Test for realization of distribution
    NumericalPoint oneRealization = distribution.getRealization();
    fullprint << "oneRealization=" << oneRealization << std::endl;

    // Test for sampling
    UnsignedInteger size = 10000;
    NumericalSample oneSample = distribution.getSample( size );
    fullprint << "oneSample first=" << oneSample[0] << " last=" << oneSample[size - 1] << std::endl;
    fullprint << "mean=" << oneSample.computeMean() << std::endl;
    fullprint << "covariance=" << oneSample.computeCovariance() << std::endl;
    size = 100;
    for (UnsignedInteger i = 0; i < 2; ++i)
    {
      fullprint << "Kolmogorov test for the generator, sample size=" << size << " is " << (FittingTest::Kolmogorov(distribution.getSample(size), distribution).getBinaryQualityMeasure() ? "accepted" : "rejected") << std::endl;
      size *= 10;
    }

    // Define a point
    NumericalPoint point( distribution.getDimension(), 1.0 );
    fullprint << "Point= " << point << std::endl;

    // Show PDF and CDF of point
    NumericalScalar eps(1e-5);
    NumericalPoint DDF = distribution.computeDDF( point );
    fullprint << "ddf     =" << DDF << std::endl;
    fullprint << "ddf (FD)=" << NumericalPoint(1, (distribution.computePDF( point + NumericalPoint(1, eps) ) - distribution.computePDF( point  + NumericalPoint(1, -eps) )) / (2.0 * eps)) << std::endl;
    NumericalScalar LPDF = distribution.computeLogPDF( point );
    fullprint << "log pdf=" << LPDF << std::endl;
    NumericalScalar PDF = distribution.computePDF( point );
    fullprint << "pdf     =" << PDF << std::endl;
    fullprint << "pdf (FD)=" << (distribution.computeCDF( point + NumericalPoint(1, eps) ) - distribution.computeCDF( point  + NumericalPoint(1, -eps) )) / (2.0 * eps) << std::endl;
    NumericalScalar CDF = distribution.computeCDF( point );
    fullprint << "cdf=" << CDF << std::endl;
    NumericalScalar CCDF = distribution.computeComplementaryCDF( point );
    fullprint << "ccdf=" << CCDF << std::endl;
    NumericalScalar Survival = distribution.computeSurvivalFunction( point );
    fullprint << "survival=" << Survival << std::endl;
    NumericalPoint PDFgr = distribution.computePDFGradient( point );
    fullprint << "pdf gradient     =" << PDFgr << std::endl;
    NumericalPoint PDFgrFD(3);
    PDFgrFD[0] = (Student(distribution.getNu() + eps, distribution.getMean(), distribution.getSigma(), distribution.getCorrelation()).computePDF(point) -
                  Student(distribution.getNu() - eps, distribution.getMean(), distribution.getSigma(), distribution.getCorrelation()).computePDF(point)) / (2.0 * eps);
    PDFgrFD[1] = (Student(distribution.getNu(), distribution.getMean() + NumericalPoint(1, eps), distribution.getSigma(), distribution.getCorrelation()).computePDF(point) -
                  Student(distribution.getNu(), distribution.getMean() - NumericalPoint(1, eps), distribution.getSigma(), distribution.getCorrelation()).computePDF(point)) / (2.0 * eps);
    PDFgrFD[2] = (Student(distribution.getNu(), distribution.getMean(), distribution.getSigma() + NumericalPoint(1, eps), distribution.getCorrelation()).computePDF(point) -
                  Student(distribution.getNu(), distribution.getMean(), distribution.getSigma() - NumericalPoint(1, eps), distribution.getCorrelation()).computePDF(point)) / (2.0 * eps);
    fullprint << "pdf gradient (FD)=" << PDFgrFD << std::endl;
    NumericalPoint CDFgr = distribution.computeCDFGradient( point );
    fullprint << "cdf gradient     =" << CDFgr << std::endl;
    NumericalPoint CDFgrFD(3);
    CDFgrFD[0] = (Student(distribution.getNu() + eps, distribution.getMean(), distribution.getSigma(), distribution.getCorrelation()).computeCDF(point) -
                  Student(distribution.getNu() - eps, distribution.getMean(), distribution.getSigma(), distribution.getCorrelation()).computeCDF(point)) / (2.0 * eps);
    CDFgrFD[1] = (Student(distribution.getNu(), distribution.getMean() + NumericalPoint(1, eps), distribution.getSigma(), distribution.getCorrelation()).computeCDF(point) -
                  Student(distribution.getNu(), distribution.getMean() - NumericalPoint(1, eps), distribution.getSigma(), distribution.getCorrelation()).computeCDF(point)) / (2.0 * eps);
    CDFgrFD[2] = (Student(distribution.getNu(), distribution.getMean(), distribution.getSigma() + NumericalPoint(1, eps), distribution.getCorrelation()).computeCDF(point) -
                  Student(distribution.getNu(), distribution.getMean(), distribution.getSigma() - NumericalPoint(1, eps), distribution.getCorrelation()).computeCDF(point)) / (2.0 * eps);
    fullprint << "cdf gradient (FD)=" << CDFgrFD << std::endl;
    NumericalPoint quantile = distribution.computeQuantile( 0.95 );
    fullprint << "quantile=" << quantile << std::endl;
    fullprint << "cdf(quantile)=" << distribution.computeCDF(quantile) << std::endl;
    NumericalPoint mean = distribution.getMean();
    fullprint << "mean=" << mean << std::endl;
    NumericalPoint standardDeviation = distribution.getStandardDeviation();
    fullprint << "standard deviation=" << standardDeviation << std::endl;
    NumericalPoint skewness = distribution.getSkewness();
    fullprint << "skewness=" << skewness << std::endl;
    NumericalPoint kurtosis = distribution.getKurtosis();
    fullprint << "kurtosis=" << kurtosis << std::endl;
    CovarianceMatrix covariance = distribution.getCovariance();
    fullprint << "covariance=" << covariance << std::endl;
    CovarianceMatrix correlation = distribution.getCorrelation();
    fullprint << "correlation=" << correlation << std::endl;
    CovarianceMatrix spearman = distribution.getSpearmanCorrelation();
    fullprint << "spearman=" << spearman << std::endl;
    CovarianceMatrix kendall = distribution.getKendallTau();
    fullprint << "kendall=" << kendall << std::endl;
    Student::NumericalPointWithDescriptionCollection parameters = distribution.getParametersCollection();
    fullprint << "parameters=" << parameters << std::endl;
    for (UnsignedInteger i = 0; i < 6; ++i) fullprint << "standard moment n=" << i << ", value=" << distribution.getStandardMoment(i) << std::endl;
    fullprint << "Standard representative=" << distribution.getStandardRepresentative()->__str__() << std::endl;

    // Specific to this distribution
    NumericalScalar beta(point.normSquare());
    NumericalScalar densityGenerator(distribution.computeDensityGenerator(beta));
    fullprint << "density generator=" << densityGenerator << std::endl;
    fullprint << "pdf via density generator=" << distribution.EllipticalDistribution::computePDF(point) << std::endl;
    NumericalScalar densityGeneratorDerivative(distribution.computeDensityGeneratorDerivative(beta));
    fullprint << "density generator derivative     =" << densityGeneratorDerivative << std::endl;
    fullprint << "density generator derivative (FD)=" << (distribution.computeDensityGenerator(beta + eps) - distribution.computeDensityGenerator(beta - eps)) / (2.0 * eps) << std::endl;
    NumericalScalar densityGeneratorSecondDerivative(distribution.computeDensityGeneratorSecondDerivative(beta));
    fullprint << "density generator second derivative     =" << densityGeneratorSecondDerivative << std::endl;
    fullprint << "density generator second derivative (FD)=" << (distribution.computeDensityGeneratorDerivative(beta + eps) - distribution.computeDensityGeneratorDerivative(beta - eps)) / (2.0 * eps) << std::endl;

  }
  catch (TestFailed & ex)
  {
    std::cerr << ex << std::endl;
    return ExitCode::Error;
  }


  return ExitCode::Success;
}
